@@ -5,7 +5,6 @@ See the Manifest class.
 """
 
 from collections.abc import Sequence
-from collections import defaultdict
 import multiprocessing
 import os
 from typing import Dict
@@ -201,28 +200,17 @@ class Manifest:
         if not stripped_root:
             return
 
-        cursor = self.database.connection.cursor()
-
         def get_hyperthought_id(name, hyperthought_id_path):
-            # TODO:  Remove SQL from this module.  See IC-7272.
-            sql = """
-            SELECT hyperthought_id
-            FROM File
-            WHERE
-                name = :name
-                AND
-                hyperthought_id_path = :hyperthought_id_path
-            """
-            cursor.execute(sql, {
-                "name": name,
-                "hyperthought_id_path": hyperthought_id_path,
-            })
-            row = cursor.fetchone()
+            """Get a hyperthought_id given name and hyperthought_id_path."""
+            file_ = self.database.get_file(
+                name=name,
+                hyperthought_id_path=hyperthought_id_path,
+            )
 
-            if not row:
+            if not file_:
                 return None
 
-            return row["hyperthought_id"]
+            return file_["hyperthought_id"]
 
         root_folders = stripped_root.split("/")
         hyperthought_id_path = ","
@@ -742,6 +730,7 @@ class Manifest:
 
         self.database.connection.close()
 
+
 def from_json(manifest_data: Dict, manifest_database_file: str) -> Manifest:
     """
     Create and return a manifest with the given (JSON) data.
